//
//  AGSectionView.h
//  AGSectionView
//
//  Created by Seth Willits on 12/29/06.
//  Copyright 2006 Araelium Group. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "AGSection.h"


typedef enum _AGSectionHeaderStyle {
	AGSectionHeaderBlueGradientStyle = 0,
	AGSectionHeaderSlimGraphiteStyle = 1,
	AGSectionHeaderPurpleXcodeStyle = 2,
	AGSectionHeaderSimpleLightGradientBarStyle = 3,
	AGSectionHeaderSlimSierraStyle = 4,
	AGSectionHeaderModernEmptyStyle = 5,
} AGSectionHeaderStyle;


@interface AGSectionView : NSView {
	id _delegate;
	NSMutableArray * _sections;
	NSMutableDictionary * _sectionStates;
	AGSectionHeaderStyle _headerStyle;
	NSColor * _backgroundColor;
	BOOL _isTiling;
	BOOL _needsTile;
	NSTimer * _tileTimer;
}

- (void)setDelegate:(id)delegate;
- (id)delegate;

// Accessors
- (NSUInteger)numberOfSections;
- (AGSection *)sectionAtIndex:(NSUInteger)index;
- (NSArray *)sections;
- (void)addSection:(AGSection *)section;
- (void)removeSection:(AGSection *)section;
- (BOOL)isSectionCollapsed:(AGSection *)section;

- (void)setHeaderStyle:(AGSectionHeaderStyle)style;
- (AGSectionHeaderStyle)headerStyle;

- (void)setBackgroundColor:(NSColor *)backgroundColor;
- (NSColor *)backgroundColor;

- (NSSize)sizeForSection:(AGSection *)section expanded:(BOOL)expanded;

// Actions
- (void)toggleSection:(AGSection *)section withAnimation:(BOOL)animate;
- (void)expandSection:(AGSection *)section withAnimation:(BOOL)animate;
- (void)collapseSection:(AGSection *)section withAnimation:(BOOL)animate;

@end


@interface AGSectionView (Private)
- (void)tile;
- (void)setNeedsTile:(BOOL)needsTile;
- (CGFloat)_headerHeight;
- (NSColor *)_backgroundColorForStyle;
- (void)_slideInSectionContent:(AGSection *)section;
- (void)_slideOutSectionContent:(AGSection *)section;
@end


@protocol AGSectionViewDelegate <NSObject>
- (void)sectionView:(AGSectionView *)sectionView willCollapseSection:(AGSection *)section;
- (void)sectionView:(AGSectionView *)sectionView willExpandSection:(AGSection *)section;
- (void)sectionView:(AGSectionView *)sectionView didCollapseSection:(AGSection *)section;
- (void)sectionView:(AGSectionView *)sectionView didExpandSection:(AGSection *)section;
@end

